@@ -8,12 +8,12 @@ use Class::Load qw/ load_class /;
 use Class::Accessor::Lite::Lazy (
     new     => 1,
     rw      => [qw/ team_domain token /],
-    ro_lazy => [qw/ client api auth channels chat emoji files groups im oauth rtm search stars team users /],
+    ro_lazy => [qw/ client api auth channels chat emoji files groups im oauth reactions rtm search stars team users /],
 );
 
 use WebService::Slack::WebApi::Client;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub _build_client {
     my $self = shift;
@@ -23,7 +23,7 @@ sub _build_client {
     );
 }
 
-for my $class_name (qw/ api auth channels chat emoji files groups im oauth rtm search stars team users /) {
+for my $class_name (qw/ api auth channels chat emoji files groups im oauth reactions rtm search stars team users /) {
     my $method = sprintf '%s::_build_%s', __PACKAGE__, $class_name;
     my $class  = sprintf '%s::%s', __PACKAGE__, ucfirst($class_name);
 
